;***************************************************************************
;*
;* \file      board.inc
;* \author    Wolfgang Neff
;* \version   1.0
;* \date      2016-10-23
;* \copyright (CC) BY-NO-NO
;*
;* \par History
;*      Created: 2016-10-23
;*
;* \par Header Configuration
;*
;*        === J1 ===            === J2 ===            === J3 ===            === J4 ===
;* Pin    Communication Port    Analog Port           GPIO Port             Communication Port
;*   1    PF0 (SDA/RTS)         PA0 (ADC/AREF)        PD0 (GPIO)            PC0 (SDA/RTS/PWM/CAPTURE)
;*   2    PF1 (SCL/CTS/XCK)     PA1 (ADC)             PD1 (GPIO)            PC1 (SCL/CTS/PWM/CAPTURE)
;*   3    PF2 (RXD)             PA2 (ADC/DAC)         PD2 (GPIO)            PC2 (RXD/PWM/CAPTURE)
;*   4    PF3 (TXD)             PA3 (ADC/DAC)         PD3 (GPIO)            PC3 (TXD/PWM/CAPTURE)
;*   5    PF4 (SS)              PA4 (ADC/AC_P)        PD4 (GPIO)            PC4 (SS/PWM/CAPTURE)
;*   6    PF5 (MOSI)            PA5 (ADC/AC_N)        PD5 (GPIO)            PC5 (MOSI/PWM/CAPTURE)
;*   7    PF6 (MISO)            PA6 (ADC/AC_P)        PR0 (GPIO)            PC6 (MISO/PWM)
;*   8    PF7 (SCK)             PA7 (ADC/AC_N)        PR1 (GPIO)            PC7 (SCK/PWM)
;*   9    GND                   GND                   GND                   GND
;*  10    VCC_P3V3              VCC_ANA_P3V3          VCC_USB_VBUS_P5V0     VCC_P3V3
;*
;* \note
;* This file is based on board.h. 
;* F_CPU: Default 2000000. Use default or set it via Project/Properties/Toolchain/Compiler/Symbols.
;* FreeROTS: TCC1 used as tick generator. Default 1000 low level tick interrupts per second.
;*
;***************************************************************************

.EQU PIN0_bp = 0
.EQU PIN1_bp = 1
.EQU PIN2_bp = 2
.EQU PIN3_bp = 3
.EQU PIN4_bp = 4
.EQU PIN5_bp = 5
.EQU PIN6_bp = 6
.EQU PIN7_bp = 7

.EQU PIN0_bm = 1 << PIN0_bp
.EQU PIN1_bm = 1 << PIN1_bp
.EQU PIN2_bm = 1 << PIN2_bp
.EQU PIN3_bm = 1 << PIN3_bp
.EQU PIN4_bm = 1 << PIN4_bp
.EQU PIN5_bm = 1 << PIN5_bp
.EQU PIN6_bm = 1 << PIN6_bp
.EQU PIN7_bm = 1 << PIN7_bp

/****** General-purpose input/output ******/
.EQU GPIO_LOW_PORT_DIR =  PORTD_DIR
.EQU GPIO_LOW_PORT_DIRSET = PORTD_DIRSET
.EQU GPIO_LOW_PORT_DIRCLR = PORTD_DIRCLR
.EQU GPIO_LOW_PORT_DIRTGL = PORTD_DIRTGL
.EQU GPIO_LOW_PORT_OUT = PORTD_OUT
.EQU GPIO_LOW_PORT_OUTSET = PORTD_OUTSET
.EQU GPIO_LOW_PORT_OUTCLR = PORTD_OUTCLR
.EQU GPIO_LOW_PORT_OUTTGL = PORTD_OUTTGL
.EQU GPIO_LOW_PORT_IN = PORTD_IN

.EQU GPIO_HIGH_PORT_DIR =  PORTR_DIR
.EQU GPIO_HIGH_PORT_DIRSET = PORTR_DIRSET
.EQU GPIO_HIGH_PORT_DIRCLR = PORTR_DIRCLR
.EQU GPIO_HIGH_PORT_DIRTGL = PORTR_DIRTGL
.EQU GPIO_HIGH_PORT_OUT = PORTR_OUT
.EQU GPIO_HIGH_PORT_OUTSET = PORTR_OUTSET
.EQU GPIO_HIGH_PORT_OUTCLR = PORTR_OUTCLR
.EQU GPIO_HIGH_PORT_OUTTGL = PORTR_OUTTGL
.EQU GPIO_HIGH_PORT_IN = PORTR_IN

.EQU GPIO_LOW_PINS_gp = 0
.EQU GPIO_LOW_PINS_gm = 0x3F
.EQU GPIO_HIGH_PINS_gp = 6
.EQU GPIO_HIGH_PINS_gm = 0xC0

.EQU GPIO0_PIN_bp = 0
.EQU GPIO1_PIN_bp = 1
.EQU GPIO2_PIN_bp = 2
.EQU GPIO3_PIN_bp = 3
.EQU GPIO4_PIN_bp = 4
.EQU GPIO5_PIN_bp = 5
.EQU GPIO6_PIN_bp = 0
.EQU GPIO7_PIN_bp = 1

.EQU GPIO0_PIN_bm = 1 << GPIO0_PIN_bp
.EQU GPIO1_PIN_bm = 1 << GPIO1_PIN_bp
.EQU GPIO2_PIN_bm = 1 << GPIO2_PIN_bp
.EQU GPIO3_PIN_bm = 1 << GPIO3_PIN_bp
.EQU GPIO4_PIN_bm = 1 << GPIO4_PIN_bp
.EQU GPIO5_PIN_bm = 1 << GPIO5_PIN_bp
.EQU GPIO6_PIN_bm = 1 << GPIO6_PIN_bp
.EQU GPIO7_PIN_bm = 1 << GPIO7_PIN_bp

.EQU GPIO0_PINCTRL = PORTD_PIN0CTRL
.EQU GPIO1_PINCTRL = PORTD_PIN1CTRL
.EQU GPIO2_PINCTRL = PORTD_PIN2CTRL
.EQU GPIO3_PINCTRL = PORTD_PIN3CTRL
.EQU GPIO4_PINCTRL = PORTD_PIN4CTRL
.EQU GPIO5_PINCTRL = PORTD_PIN5CTRL
.EQU GPIO6_PINCTRL = PORTR_PIN0CTRL
.EQU GPIO7_PINCTRL = PORTR_PIN1CTRL

;****** Active low LEDs ******
;*   VCC_P3V3
;*      +
;*      |
;*      V -> EL17-21UYC/A2
;*      -
;*      |
;*      |
;*     .-.
;*     | | 220R
;*     | |
;*     '-'
;*      |
;*      |
;*  PE[7..0]
.EQU LED_PORT_DIR = PORTE_DIR
.EQU LED_PORT_DIRSET = PORTE_DIRSET
.EQU LED_PORT_DIRCLR = PORTE_DIRCLR
.EQU LED_PORT_DIRTGL = PORTE_DIRTGL
.EQU LED_PORT_OUT = PORTE_OUT
.EQU LED_PORTE_OUTSET = PORTE_OUTSET
.EQU LED_PORT_OUTCLR = PORTE_OUTCLR
.EQU LED_PORT_OUTTGL = PORTE_OUTTGL

.EQU LED_PINS_gp = 0
.EQU LED_PINS_gm = 0xFF

.EQU LED0_PIN_bp = 0
.EQU LED1_PIN_bp = 1
.EQU LED2_PIN_bp = 2
.EQU LED3_PIN_bp = 3
.EQU LED4_PIN_bp = 4
.EQU LED5_PIN_bp = 5
.EQU LED6_PIN_bp = 6
.EQU LED7_PIN_bp = 7

.EQU LED0_PIN_bm = 1 << LED0_PIN_bp
.EQU LED1_PIN_bm = 1 << LED1_PIN_bp
.EQU LED2_PIN_bm = 1 << LED2_PIN_bp
.EQU LED3_PIN_bm = 1 << LED3_PIN_bp
.EQU LED4_PIN_bm = 1 << LED4_PIN_bp
.EQU LED5_PIN_bm = 1 << LED5_PIN_bp
.EQU LED6_PIN_bm = 1 << LED6_PIN_bp
.EQU LED7_PIN_bm = 1 << LED7_PIN_bp

.EQU LED0_PINCTRL = PORTE_PIN0CTRL
.EQU LED1_PINCTRL = PORTE_PIN1CTRL
.EQU LED2_PINCTRL = PORTE_PIN2CTRL
.EQU LED3_PINCTRL = PORTE_PIN3CTRL
.EQU LED4_PINCTRL = PORTE_PIN4CTRL
.EQU LED5_PINCTRL = PORTE_PIN5CTRL
.EQU LED6_PINCTRL = PORTE_PIN6CTRL
.EQU LED7_PINCTRL = PORTE_PIN7CTRL

;****** Active low push buttons ******
;*  Header J3
;*     |
;*    .-.
;*    | | 330R
;*    | |
;*    '-'
;*     |
;*     |
;*   | o
;* |=|>
;*   | o
;*     |
;*     |
;*    ===
;*    GND
.EQU BUTTON_LOW_PORT_DIR =  PORTD_DIR
.EQU BUTTON_LOW_PORT_DIRSET = PORTD_DIRSET
.EQU BUTTON_LOW_PORT_DIRCLR = PORTD_DIRCLR
.EQU BUTTON_LOW_PORT_DIRTGL = PORTD_DIRTGL
.EQU BUTTON_LOW_PORT_IN = PORTD_IN

.EQU BUTTON_HIGH_PORT_DIR =  PORTR_DIR
.EQU BUTTON_HIGH_PORT_DIRSET = PORTR_DIRSET
.EQU BUTTON_HIGH_PORT_DIRCLR = PORTR_DIRCLR
.EQU BUTTON_HIGH_PORT_DIRTGL = PORTR_DIRTGL
.EQU BUTTON_HIGH_PORT_IN = PORTR_IN

.EQU BUTTON_LOW_PINS_gp = 0
.EQU BUTTON_LOW_PINS_gm = 0x3F
.EQU BUTTON_HIGH_PINS_gp = 6
.EQU BUTTON_HIGH_PINS_gm = 0xC0

.EQU BUTTON0_PIN_bp = 0
.EQU BUTTON1_PIN_bp = 1
.EQU BUTTON2_PIN_bp = 2
.EQU BUTTON3_PIN_bp = 3
.EQU BUTTON4_PIN_bp = 4
.EQU BUTTON5_PIN_bp = 5
.EQU BUTTON6_PIN_bp = 0
.EQU BUTTON7_PIN_bp = 1

.EQU BUTTON0_PIN_bm = 1 << BUTTON0_PIN_bp
.EQU BUTTON1_PIN_bm = 1 << BUTTON1_PIN_bp
.EQU BUTTON2_PIN_bm = 1 << BUTTON2_PIN_bp
.EQU BUTTON3_PIN_bm = 1 << BUTTON3_PIN_bp
.EQU BUTTON4_PIN_bm = 1 << BUTTON4_PIN_bp
.EQU BUTTON5_PIN_bm = 1 << BUTTON5_PIN_bp
.EQU BUTTON6_PIN_bm = 1 << BUTTON6_PIN_bp
.EQU BUTTON7_PIN_bm = 1 << BUTTON7_PIN_bp

.EQU BUTTON0_PINCTRL = PORTD_PIN0CTRL
.EQU BUTTON1_PINCTRL = PORTD_PIN1CTRL
.EQU BUTTON2_PINCTRL = PORTD_PIN2CTRL
.EQU BUTTON3_PINCTRL = PORTD_PIN3CTRL
.EQU BUTTON4_PINCTRL = PORTD_PIN4CTRL
.EQU BUTTON5_PINCTRL = PORTD_PIN5CTRL
.EQU BUTTON6_PINCTRL = PORTR_PIN0CTRL
.EQU BUTTON7_PINCTRL = PORTR_PIN1CTRL

/****** USART-to-USB gateway ******/
.EQU USART0_RX_PIN_bp = 2
.EQU USART0_TX_PIN_bp = 3
.EQU USART1_RX_PIN_bp = 6
.EQU USART1_TX_PIN_bp = 7

.EQU USART0_RX_PIN_bm = 1 << USART0_RX_PIN_bp
.EQU USART0_TX_PIN_bm = 1 << USART0_TX_PIN_bp
.EQU USART1_RX_PIN_bm = 1 << USART1_RX_PIN_bp
.EQU USART1_TX_PIN_bm = 1 << USART1_TX_PIN_bp

.EQU USB_USART_PORT_DIR =  PORTC_DIR
.EQU USB_USART_PORT_DIRSET = PORTC_DIRSET
.EQU USB_USART_PORT_DIRCLR = PORTC_DIRCLR
.EQU USB_USART_PORT_DIRTGL = PORTC_DIRTGL

.EQU USB_USART_RX_PIN_bm = USART0_RX_PIN_bm
.EQU USB_USART_TX_PIN_bm = USART0_TX_PIN_bm

.EQU USB_USART_MODULE_DATA = USARTC0_DATA
.EQU USB_USART_MODULE_STATUS = USARTC0_STATUS
.EQU USB_USART_MODULE_CTRLA = USARTC0_CTRLA
.EQU USB_USART_MODULE_CTRLB = USARTC0_CTRLB
.EQU USB_USART_MODULE_CTRLC = USARTC0_CTRLC
.EQU USB_USART_MODULE_BAUDCTRLA = USARTC0_BAUDCTRLA
.EQU USB_USART_MODULE_BAUDCTRLB = USARTC0_BAUDCTRLB

.EQU USB_USART_RXC_vect = USARTC0_RXC_vect
.EQU USB_USART_DRE_vect = USARTC0_DRE_vect

;****** Light sensor ******
;*    VCC_P3V3
;*       +
;*       |
;*      .-.
;*      | | 100k
;*      | |
;*      '-'
;*       |
;*       o--- Lightsensor
;*       |
;* ->  |/
;*    -|   Phototransistor
;* ->  |>  TEMT6000
;*       |
;*       |
;*      ===
;*      GND
.EQU LIGHT_SENSOR_SIGNAL_PORT_DIR = PORTB_DIR
.EQU LIGHT_SENSOR_SIGNAL_PORT_DIRSET = PORTB_DIRSET
.EQU LIGHT_SENSOR_SIGNAL_PORT_DIRCLR = PORTB_DIRCLR
.EQU LIGHT_SENSOR_SIGNAL_PORT_DIRTGL = PORTB_DIRTGL
.EQU LIGHT_SENSOR_SIGNAL_PORT_IN = PORTB_IN
.EQU LIGHT_SENSOR_SIGNAL_PIN_bp = 1
.EQU LIGHT_SENSOR_SIGNAL_PIN_bm = 1 << LIGHT_SENSOR_SIGNAL_PIN_bp

.EQU LIGHT_SENSOR_ADC_CTRLA = ADCB_CTRLA
.EQU LIGHT_SENSOR_ADC_CTRLB = ADCB_CTRLB
.EQU LIGHT_SENSOR_ADC_REFCTRL = ADCB_REFCTRL
.EQU LIGHT_SENSOR_ADC_INTFLAGS = ADCB_INTFLAGS
.EQU LIGHT_SENSOR_ADC_PRESCALER = ADCB_PRESCALER
.EQU LIGHT_SENSOR_ADC_INPUT = ADC_CH_MUXPOS_PIN1_gc

.EQU LIGHT_SENSOR_ADC_CH0_RES = ADCB_CH0_RES
.EQU LIGHT_SENSOR_ADC_CH0_CTRL = ADCB_CH0_CTRL
.EQU LIGHT_SENSOR_ADC_CH0_MUXCTRL = ADCB_CH0_MUXCTRL
.EQU LIGHT_SENSOR_ADC_CH0_INTCTRL = ADCB_CH0_INTCTRL
.EQU LIGHT_SENSOR_ADC_CH0_INTFLAGS = ADCB_CH0_INTFLAGS

.EQU LIGHT_SENSOR_ADC_CH1_RES = ADCB_CH1_RES
.EQU LIGHT_SENSOR_ADC_CH1_CTRL = ADCB_CH1_CTRL
.EQU LIGHT_SENSOR_ADC_CH1_MUXCTRL = ADCB_CH1_MUXCTRL
.EQU LIGHT_SENSOR_ADC_CH1_INTCTRL = ADCB_CH1_INTCTRL
.EQU LIGHT_SENSOR_ADC_CH1_INTFLAGS = ADCB_CH1_INTFLAGS

.EQU LIGHT_SENSOR_ADC_CH2_RES = ADCB_CH2_RES
.EQU LIGHT_SENSOR_ADC_CH2_CTRL = ADCB_CH2_CTRL
.EQU LIGHT_SENSOR_ADC_CH2_MUXCTRL = ADCB_CH2_MUXCTRL
.EQU LIGHT_SENSOR_ADC_CH2_INTCTRL = ADCB_CH2_INTCTRL
.EQU LIGHT_SENSOR_ADC_CH2_INTFLAGS = ADCB_CH2_INTFLAGS

.EQU LIGHT_SENSOR_ADC_CH3_RES = ADCB_CH3_RES
.EQU LIGHT_SENSOR_ADC_CH3_CTRL = ADCB_CH3_CTRL
.EQU LIGHT_SENSOR_ADC_CH3_MUXCTRL = ADCB_CH3_MUXCTRL
.EQU LIGHT_SENSOR_ADC_CH3_INTCTRL = ADCB_CH3_INTCTRL
.EQU LIGHT_SENSOR_ADC_CH3_INTFLAGS = ADCB_CH3_INTFLAGS

;****** Temperature sensor ******
;*  VCC_P3V3
;*     +
;*     |
;*    .-.
;*    | | 1M
;*    | |
;*    '-'
;*     |
;*     o---- NTC_TEMP
;*     |
;*    .-.
;*    | |<-- NCP18WF104J03RB
;*    | |
;*    '-'
;*     |
;*     '---- NTC_EN
.EQU TEMPERATURE_SENSOR_SIGNAL_PORT_DIR = PORTB_DIR
.EQU TEMPERATURE_SENSOR_SIGNAL_PORT_DIRSET = PORTB_DIRSET
.EQU TEMPERATURE_SENSOR_SIGNAL_PORT_DIRCLR = PORTB_DIRCLR
.EQU TEMPERATURE_SENSOR_SIGNAL_PORT_DIRTGL = PORTB_DIRTGL
.EQU TEMPERATURE_SENSOR_SIGNAL_PORT_IN = PORTB_IN
.EQU TEMPERATURE_SENSOR_SIGNAL_PIN_bp = 0
.EQU TEMPERATURE_SENSOR_SIGNAL_PIN_bm = 1 << TEMPERATURE_SENSOR_SIGNAL_PIN_bp

.EQU TEMPERATURE_SENSOR_ENABLE_PORT_DIR =  PORTB_DIR
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_DIRSET =  PORTB_DIRSET
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_DIRCLR =  PORTB_DIRCLR
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_DIRTGL =  PORTB_DIRTGL
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_OUT =  PORTB_OUT
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_OUTSET =  PORTB_OUTSET
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_OUTCLR =  PORTB_OUTCLR
.EQU TEMPERATURE_SENSOR_ENABLE_PORT_OUTTGL =  PORTB_OUTTGL
.EQU TEMPERATURE_SENSOR_ENABLE_PIN_bp = 3
.EQU TEMPERATURE_SENSOR_ENABLE_PIN_bm = 1 << TEMPERATURE_SENSOR_ENABLE_PIN_bp

.EQU TEMPERATURE_SENSOR_ADC_CTRLA = ADCB_CTRLA
.EQU TEMPERATURE_SENSOR_ADC_CTRLB = ADCB_CTRLB
.EQU TEMPERATURE_SENSOR_ADC_REFCTRL = ADCB_REFCTRL
.EQU TEMPERATURE_SENSOR_ADC_INTFLAGS = ADCB_INTFLAGS
.EQU TEMPERATURE_SENSOR_ADC_PRESCALER = ADCB_PRESCALER
.EQU TEMPERATURE_SENSOR_ADC_INPUT = ADC_CH_MUXPOS_PIN0_gc

.EQU TEMPERATURE_SENSOR_ADC_CH0_RES = ADCB_CH0_RES
.EQU TEMPERATURE_SENSOR_ADC_CH0_CTRL = ADCB_CH0_CTRL
.EQU TEMPERATURE_SENSOR_ADC_CH0_MUXCTRL = ADCB_CH0_MUXCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH0_INTCTRL = ADCB_CH0_INTCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH0_INTFLAGS = ADCB_CH0_INTFLAGS

.EQU TEMPERATURE_SENSOR_ADC_CH1_RES = ADCB_CH1_RES
.EQU TEMPERATURE_SENSOR_ADC_CH1_CTRL = ADCB_CH1_CTRL
.EQU TEMPERATURE_SENSOR_ADC_CH1_MUXCTRL = ADCB_CH1_MUXCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH1_INTCTRL = ADCB_CH1_INTCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH1_INTFLAGS = ADCB_CH1_INTFLAGS

.EQU TEMPERATURE_SENSOR_ADC_CH2_RES = ADCB_CH2_RES
.EQU TEMPERATURE_SENSOR_ADC_CH2_CTRL = ADCB_CH2_CTRL
.EQU TEMPERATURE_SENSOR_ADC_CH2_MUXCTRL = ADCB_CH2_MUXCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH2_INTCTRL = ADCB_CH2_INTCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH2_INTFLAGS = ADCB_CH2_INTFLAGS

.EQU TEMPERATURE_SENSOR_ADC_CH3_RES = ADCB_CH3_RES
.EQU TEMPERATURE_SENSOR_ADC_CH3_CTRL = ADCB_CH3_CTRL
.EQU TEMPERATURE_SENSOR_ADC_CH3_MUXCTRL = ADCB_CH3_MUXCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH3_INTCTRL = ADCB_CH3_INTCTRL
.EQU TEMPERATURE_SENSOR_ADC_CH3_INTFLAGS = ADCB_CH3_INTFLAGS

;****** Speaker ******
;*               1u       TPA0253DGQR
;*               ||   ___     __
;* AUDIO_OUT  ---||--|___|--o|  |      .---|
;*               ||   30k    |  |o-----|   |
;*                           |  |o-----|   |
;* AUDIO_SD    --------o----o|__|      '---|
;*                     |              NDT-03C
;*                    .-.
;*                    | | 100k
;*                    | |
;*                    '-'
;*                     |
;*                     |
;*                    ===
;*                    GND
.EQU SPEAKER_SIGNAL_PORT_DIR = PORTB_DIR
.EQU SPEAKER_SIGNAL_PORT_DIRSET = PORTB_DIRSET
.EQU SPEAKER_SIGNAL_PORT_DIRCLR = PORTB_DIRCLR
.EQU SPEAKER_SIGNAL_PORT_DIRTGL = PORTB_DIRTGL
.EQU SPEAKER_SIGNAL_PORT_OUT = PORTB_OUT
.EQU SPEAKER_SIGNAL_PORTE_OUTSET = PORTB_OUTSET
.EQU SPEAKER_SIGNAL_PORT_OUTCLR = PORTB_OUTCLR
.EQU SPEAKER_SIGNAL_PORT_OUTTGL = PORTB_OUTTGL
.EQU SPEAKER_SIGNAL_PIN_bp = 2
.EQU SPEAKER_SIGNAL_PIN_bm = 1 << SPEAKER_SIGNAL_PIN_bp

.EQU SPEAKER_SHUTDOWN_PORT_DIR = PORTQ_DIR
.EQU SPEAKER_SHUTDOWN_PORT_DIRSET = PORTQ_DIRSET
.EQU SPEAKER_SHUTDOWN_PORT_DIRCLR = PORTQ_DIRCLR
.EQU SPEAKER_SHUTDOWN_PORT_DIRTGL = PORTQ_DIRTGL
.EQU SPEAKER_SHUTDOWN_PORT_OUT = PORTQ_OUT
.EQU SPEAKER_SHUTDOWN_PORTE_OUTSET = PORTQ_OUTSET
.EQU SPEAKER_SHUTDOWN_PORT_OUTCLR = PORTQ_OUTCLR
.EQU SPEAKER_SHUTDOWN_PORT_OUTTGL = PORTQ_OUTTGL
.EQU SPEAKER_SHUTDOWN_PIN_bp = 3
.EQU SPEAKER_SHUTDOWN_PIN_bm = 1 << SPEAKER_SIGNAL_PIN_bp

.EQU SPEAKER_DAC_CTRLA = DACB_CTRLA
.EQU SPEAKER_DAC_CTRLB = DACB_CTRLB
.EQU SPEAKER_DAC_CTRLC = DACB_CTRLC
.EQU SPEAKER_DAC_EVCTRL = DACB_EVCTRL
.EQU SPEAKER_DAC_TIMCTRL = DACB_TIMCTRL
.EQU SPEAKER_DAC_STATUS = DACB_STATUS
.EQU SPEAKER_DAC_CH0DATA = DACB_CH0DATA
.EQU SPEAKER_DAC_CH1DATA = DACB_CH1DATA

;****** Internal oscillator ******
.EQU OSC_INTERNAL_2HZ = 2000000
.EQU OSC_INTERNAL_32HZ = 32000000

;****** Default oscillator ******
.EQU OSC_DEFAULT_HZ = OSC_INTERNAL_2HZ

;** MACRO ******************************************************************
;*
;* gpio_in Rd
;*
;* Read the GPIO state.
;*
;* \param[out] Rd   The state of the GPIO.
;*
;* Low registers used: R0
;* High registers used: None
;*
;***************************************************************************
.MACRO gpio_in
    lds r0, GPIO_HIGH_PORT_IN
	lsl r0
	lsl r0
	lsl r0
	lsl r0
	lsl r0
	lsl r0
    lds @0, GPIO_LOW_PORT_IN
	lsl @0
	lsl @0
	lsr @0
	lsr @0
    ANDI @0, GPIO_LOW_PINS_gm
    or @0, r0
.ENDMACRO

;** MACRO ******************************************************************
;*
;* gpio_out Rr
;*
;* Write to GPIO.
;*
;* \param      Rd   The value to be written.
;*
;* Low registers used: R0
;* High registers used: None
;*
;***************************************************************************
.MACRO gpio_out
    mov r0, @0
	lsr r0
	lsr r0
	lsr r0
	lsr r0
	lsr r0
	lsr r0
    sts GPIO_LOW_PORT_OUT, @0
    sts GPIO_HIGH_PORT_OUT, r0
.ENDMACRO

;** MACRO ******************************************************************
;*
;* buttons_read Rd
;*
;* Read the push-button state.
;*
;* \param[out] Rd   The state of the push-buttons
;*
;* Low registers used: R0
;* High registers used: None
;*
;* Note: The push-buttons are active low. GPIO and push-buttons share their
;* ports.
;*
;***************************************************************************
.MACRO buttons_read
    gpio_in @0
.ENDMACRO
