;***************************************************************************
;*
;* \file      convert.inc
;* \author    Wolfgang Neff
;* \version   1.0
;* \date      2016-11-01
;* \copyright (CC) BY-NO-NO
;*
;* \par History
;*      Created: 2016-11-01
;*
;***************************************************************************

;** SUBROUTINE *************************************************************
;*
;* bin2asc16
;*
;* 16-bit binary to ASCII conversion.
;*
;* \param[in]   R0   Low byte of the number
;* \param[in]   R1   High byte of the number
;* \param[out]  R0   First digit of the converted number - rightmost
;* \param[out]  R1   Second digit of the converted number
;* \param[out]  R2   Third digit of the converted number
;* \param[out]  R3   Fourth digit of the converted number
;* \param[out]  R4   Fifth digit of the converted number - leftmost
;*
;* This subroutine converts a 16-bit number (r1:r0) to a 5-digit
;* ASCII number (r4:r3:r2:r1:r0). Leading Xeros are represented
;* by blanks.
;*
;* Low registers used: None
;* High registers used: R16, R17
;* Pointers used: X
;* I/O Memory used: GPIO0, GPIO1, GPIO2, GPIO3, GPIO4
;*
;***************************************************************************
bin2asc16:
    rcall bin2BCD16
	ldi r16, 0x0F
	and r2, r16
	out GPIO_GPIOR4, r2
	mov r2, r1
	swap r2
	and r2, r16
	out GPIO_GPIOR3, r2
	and r1, r16
	out GPIO_GPIOR2, r1
	mov r1, r0
	swap r1
	and r1, r16
	out GPIO_GPIOR1, r1
	and r0, r16
	out GPIO_GPIOR0, r0
	clr XH
	ldi r16, ' '
	ldi XL, GPIO_GPIOR5
_bin2ASC16_loop1__:
	ld r0, -X
    cpi XL, GPIO_GPIOR0
	breq _bin2ASC16_cont1__
	tst r0
	brne _bin2ASC16_cont1__
	st X, r16
	rjmp _bin2ASC16_loop1__
_bin2ASC16_cont1__:
	ldi r16, '0'
_bin2ASC16_loop2__:
	add r0, r16
	st X, r0
    cpi XL, GPIO_GPIOR0
	breq _bin2ASC16_cont2__
	ld r0, -X
	rjmp _bin2ASC16_loop2__
_bin2ASC16_cont2__:
	in r0, GPIO_GPIOR0
	in r1, GPIO_GPIOR1
	in r2, GPIO_GPIOR2
	in r3, GPIO_GPIOR3
	in r4, GPIO_GPIOR4
	ret

;** SUBROUTINE *************************************************************
;*
;* bin2bcd16
;*
;* 16-bit binary to BCD conversion.
;*
;* \param[in]   R0   Low byte of the number
;* \param[in]   R1   High byte of the number
;* \param[out]  R0   First packed BCD of the converted number - rightmost
;* \param[out]  R1   Second packed BCD of the converted number
;* \param[out]  R2   Third packed BCD of the converted number - leftmost
;*
;* This subroutine converts a 16-bit number (r1:r0) to a 5-digit
;* packed BCD number represented by 3 bytes (r2:r1:r0). The MSD
;* of the 5-digit number is placed in the lowermost nibble of r2.
;*
;* Low registers used: R3, R4
;* High registers used: R16, R17
;* Pointers used: X
;* I/O Memory used: GPIO0, GPIO1, GPIO2
;*
;* Note: This subroutine is based on AVR204
;*
;***************************************************************************
bin2bcd16:
	mov r3, r0
	mov r4, r1
    ldi r16, 16
    clr r2
    clr r1
    clr r0
    clr XH
_bin2BCD16_loop1__:
    lsl r3
    rol r4
    rol r0
    rol r1
    rol r2
    dec r16
    brne _bin2BCD16_cont__
    ret
_bin2BCD16_cont__:
    out GPIO_GPIOR0, r0
    out GPIO_GPIOR1, r1
    out GPIO_GPIOR2, r2
    ldi XL, GPIO_GPIOR3
_bin2BCD16_loop2__:
    ld r17, -X
    subi r17, -0x03
    sbrc r17, 3
    st X, r17
    ld r17, X
    subi r17, -0x30
    sbrc r17, 7
    st X, r17
    cpi XL, GPIO_GPIOR0
    brne _bin2BCD16_loop2__
    in r0, GPIO_GPIOR0
    in r1, GPIO_GPIOR1
    in r2, GPIO_GPIOR2
    rjmp _bin2BCD16_loop1__        

