;***************************************************************************
;*
;* \file      debounce.inc
;* \author    Wolfgang Neff
;* \version   1.0
;* \date      2016-10-25
;* \copyright (CC) BY-NO-NO
;*
;* \par History
;*      Created: 2016-10-25
;*
;***************************************************************************

;** SUBROUTINE *************************************************************
;*
;* debounce
;*  
;* Debounce a push-button
;*  
;* \param[in]  R16  The bit position of the button pin.
;* \param[in]  R17  The slot to be used for debouncing.
;* \param[in]  X    The address of the button port.
;* \param[out] R0   If button pressed 1 else o.
;*  
;* Debounce a push-button using busy wait.
;*  
;* Low registers used: R1
;* High registers used: R18, R19
;* Index registers used: X
;*
;* This code is based on http://www.mikrocontroller.net/topic/164194#1566921.
;* Please refer to switch.c for implementation details.
;*
;* Note: Variable debounce_flag must be cleared before using this routine.
;*
;* Dependencies: utils.inc
;*
;***************************************************************************
	.DSEG
debounce_flag:
    .BYTE 1

	.CSEG
debounce:
    clr r0
	movw r19:r18, r17:r16 
    lds r1, debounce_flag
	and r1, r19
    breq _debounce_key_press__
_debounce_key_release__:
    ld r1, X
	and r1, r18
    brne _debounce_cont1__
	clr r0
    ret
_debounce_cont1__:
    delay_us 98
	dec r0
    brne _debounce_key_release__
	lds r1, debounce_flag
	com r19
    and r1, r19
    sts debounce_flag, r1
	clr r0
    ret
_debounce_key_press__:
    ld r1, X
    and r1, r18
    breq _debounce_cont2__
	clr r0
    ret
_debounce_cont2__:
    delay_us 98
	dec r0
    brne _debounce_key_press__
	lds r1, debounce_flag
    or r1, r19
    sts debounce_flag, r1
    inc r0
    ret
