;***************************************************************************
;*
;* \file      switch.inc
;* \author    Wolfgang Neff
;* \version   1.0
;* \date      2016-10-25
;* \copyright (CC) BY-NO-NO
;*
;* \par History
;*      Created: 2016-10-25
;*
;***************************************************************************

;** MACRO ******************************************************************
;*
;* debouce_init
;*
;* Initializes the debounce module.
;*
;* Low registers used: R0
;* High registers used: None
;*
;* Dependencies: debounce.inc
;*
;***************************************************************************
    .MACRO debouce_init
        clr r0
	    sts debounce_flag, r0
	.ENDMACRO

;** MACRO ******************************************************************
;*
;* switch_test K
;*
;* Tests if a swtich has been pressed.
;*
;* \param    K     The number of the button
;* \returns  SREG  If button pressed NE else EQ
;*
;* Tests if a swtich on the XMEGA-A1 Xplained evaluation board has been
;* pressed. The keypress is debounced.
;*  
;* Low registers used: R0, R1
;* High registers used: R16, R17, R18, R19, R20
;* Index registers used: X
;*
;* Dependencies: board.inc, debounce.inc, utils.inc
;*
;***************************************************************************
    .MACRO switch_test
	.IF @0<0 || @0>7
        .ERROR "False switch"
	.ELIF @0<BUTTON_HIGH_PINS_gp
		ldi r16, 1<<@0
		ldi r17, 1<<@0
		ldi XL, low(BUTTON_LOW_PORT_IN)
		ldi XH, high(BUTTON_LOW_PORT_IN)
	.ELSE
		ldi r16, 1<<(@0-BUTTON_HIGH_PINS_gp)
		ldi r17, 1<<@0
		ldi XL, low(BUTTON_HIGH_PORT_IN)
		ldi XH, high(BUTTON_HIGH_PORT_IN)
    .ENDIF
	    rcall debounce
        tst r0
	.ENDMACRO

